==> istio-model-v1alpha3-5.11.0-sources.jar: annotations/io/fabric8/istio/api/networking/v1alpha3/EnvoyFilterPatchFluentImpl.java <==
package io.fabric8.istio.api.networking.v1alpha3;

import io.fabric8.kubernetes.api.builder.BaseFluent;
import java.lang.Object;
import java.lang.String;
import java.lang.Boolean;
import java.util.Map;
import java.util.LinkedHashMap;

 /**
  * Generated
  */
public class EnvoyFilterPatchFluentImpl<A extends io.fabric8.istio.api.networking.v1alpha3.EnvoyFilterPatchFluent<A>> extends io.fabric8.kubernetes.api.builder.BaseFluent<A> implements io.fabric8.istio.api.networking.v1alpha3.EnvoyFilterPatchFluent<A>{
  public EnvoyFilterPatchFluentImpl() {
  }
  public EnvoyFilterPatchFluentImpl(io.fabric8.istio.api.networking.v1alpha3.EnvoyFilterPatch instance) {
    this.withFilterClass(instance.getFilterClass()); 
    this.withOperation(instance.getOperation()); 
    this.withValue(instance.getValue()); 
  }
  private io.fabric8.istio.api.networking.v1alpha3.EnvoyFilterPatchFilterClass filterClass;
  private io.fabric8.istio.api.networking.v1alpha3.EnvoyFilterPatchOperation operation;
  private java.util.Map<java.lang.String,java.lang.Object> value;
  public io.fabric8.istio.api.networking.v1alpha3.EnvoyFilterPatchFilterClass getFilterClass() {
    return this.filterClass;
  }
  public A withFilterClass(io.fabric8.istio.api.networking.v1alpha3.EnvoyFilterPatchFilterClass filterClass) {
    this.filterClass=filterClass; return (A) this;
  }
  public java.lang.Boolean hasFilterClass() {
    return this.filterClass != null;
  }
  public io.fabric8.istio.api.networking.v1alpha3.EnvoyFilterPatchOperation getOperation() {
    return this.operation;
  }
  public A withOperation(io.fabric8.istio.api.networking.v1alpha3.EnvoyFilterPatchOperation operation) {
    this.operation=operation; return (A) this;
  }
  public java.lang.Boolean hasOperation() {
    return this.operation != null;
  }
  public A addToValue(java.lang.String key,java.lang.Object value) {
    if(this.value == null && key != null && value != null) { this.value = new java.util.LinkedHashMap<java.lang.String,java.lang.Object>(); }
    if(key != null && value != null) {this.value.put(key, value);} return (A)this;
  }
  public A addToValue(java.util.Map<java.lang.String,java.lang.Object> map) {
    if(this.value == null && map != null) { this.value = new java.util.LinkedHashMap<java.lang.String,java.lang.Object>(); }
    if(map != null) { this.value.putAll(map);} return (A)this;
  }
  public A removeFromValue(java.lang.String key) {
    if(this.value == null) { return (A) this; }
    if(key != null && this.value != null) {this.value.remove(key);} return (A)this;
  }
  public A removeFromValue(java.util.Map<java.lang.String,java.lang.Object> map) {
    if(this.value == null) { return (A) this; }
    if(map != null) { for(Object key : map.keySet()) {if (this.value != null){this.value.remove(key);}}} return (A)this;
  }
  public java.util.Map<java.lang.String,java.lang.Object> getValue() {
    return this.value;
  }
  public <K,V>A withValue(java.util.Map<java.lang.String,java.lang.Object> value) {
    if (value == null) { this.value =  null;} else {this.value = new java.util.LinkedHashMap<java.lang.String,java.lang.Object>(value);} return (A) this;
  }
  public java.lang.Boolean hasValue() {
    return this.value != null;
  }
  public boolean equals(java.lang.Object o) {
    if (this == o) return true;
    if (o == null || getClass() != o.getClass()) return false;
    EnvoyFilterPatchFluentImpl that = (EnvoyFilterPatchFluentImpl) o;
    if (filterClass != null ? !filterClass.equals(that.filterClass) :that.filterClass != null) return false;
    if (operation != null ? !operation.equals(that.operation) :that.operation != null) return false;
    if (value != null ? !value.equals(that.value) :that.value != null) return false;
    return true;
  }
  public int hashCode() {
    return java.util.Objects.hash(filterClass,  operation,  value,  super.hashCode());
  }
  
}

==> istio-model-v1alpha3-5.12.4-sources.jar: annotations/io/fabric8/istio/api/networking/v1alpha3/EnvoyFilterPatchFluentImpl.java <==
package io.fabric8.istio.api.networking.v1alpha3;

import io.fabric8.kubernetes.api.builder.BaseFluent;
import java.lang.Object;
import java.lang.String;
import java.lang.Boolean;
import java.util.Map;
import java.util.LinkedHashMap;

 /**
  * Generated
  */
public class EnvoyFilterPatchFluentImpl<A extends io.fabric8.istio.api.networking.v1alpha3.EnvoyFilterPatchFluent<A>> extends io.fabric8.kubernetes.api.builder.BaseFluent<A> implements io.fabric8.istio.api.networking.v1alpha3.EnvoyFilterPatchFluent<A>{
  public EnvoyFilterPatchFluentImpl() {
  }
  public EnvoyFilterPatchFluentImpl(io.fabric8.istio.api.networking.v1alpha3.EnvoyFilterPatch instance) {
    this.withFilterClass(instance.getFilterClass()); 
    this.withOperation(instance.getOperation()); 
    this.withValue(instance.getValue()); 
  }
  private io.fabric8.istio.api.networking.v1alpha3.EnvoyFilterPatchFilterClass filterClass;
  private io.fabric8.istio.api.networking.v1alpha3.EnvoyFilterPatchOperation operation;
  private java.util.Map<java.lang.String,java.lang.Object> value;
  public io.fabric8.istio.api.networking.v1alpha3.EnvoyFilterPatchFilterClass getFilterClass() {
    return this.filterClass;
  }
  public A withFilterClass(io.fabric8.istio.api.networking.v1alpha3.EnvoyFilterPatchFilterClass filterClass) {
    this.filterClass=filterClass; return (A) this;
  }
  public java.lang.Boolean hasFilterClass() {
    return this.filterClass != null;
  }
  public io.fabric8.istio.api.networking.v1alpha3.EnvoyFilterPatchOperation getOperation() {
    return this.operation;
  }
  public A withOperation(io.fabric8.istio.api.networking.v1alpha3.EnvoyFilterPatchOperation operation) {
    this.operation=operation; return (A) this;
  }
  public java.lang.Boolean hasOperation() {
    return this.operation != null;
  }
  public A addToValue(java.lang.String key,java.lang.Object value) {
    if(this.value == null && key != null && value != null) { this.value = new java.util.LinkedHashMap(); }
    if(key != null && value != null) {this.value.put(key, value);} return (A)this;
  }
  public A addToValue(java.util.Map<java.lang.String,java.lang.Object> map) {
    if(this.value == null && map != null) { this.value = new java.util.LinkedHashMap(); }
    if(map != null) { this.value.putAll(map);} return (A)this;
  }
  public A removeFromValue(java.lang.String key) {
    if(this.value == null) { return (A) this; }
    if(key != null && this.value != null) {this.value.remove(key);} return (A)this;
  }
  public A removeFromValue(java.util.Map<java.lang.String,java.lang.Object> map) {
    if(this.value == null) { return (A) this; }
    if(map != null) { for(Object key : map.keySet()) {if (this.value != null){this.value.remove(key);}}} return (A)this;
  }
  public java.util.Map<java.lang.String,java.lang.Object> getValue() {
    return this.value;
  }
  public <K,V>A withValue(java.util.Map<java.lang.String,java.lang.Object> value) {
    if (value == null) { this.value =  null;} else {this.value = new java.util.LinkedHashMap(value);} return (A) this;
  }
  public java.lang.Boolean hasValue() {
    return this.value != null;
  }
  public boolean equals(java.lang.Object o) {
    if (this == o) return true;
    if (o == null || getClass() != o.getClass()) return false;
    EnvoyFilterPatchFluentImpl that = (EnvoyFilterPatchFluentImpl) o;
    if (filterClass != null ? !filterClass.equals(that.filterClass) :that.filterClass != null) return false;
    if (operation != null ? !operation.equals(that.operation) :that.operation != null) return false;
    if (value != null ? !value.equals(that.value) :that.value != null) return false;
    return true;
  }
  public int hashCode() {
    return java.util.Objects.hash(filterClass,  operation,  value,  super.hashCode());
  }
  
}
